@@ -8,11 +8,12 @@ skip_if_error <- function(expr) {
 }
 
 skip_if_remote_src <- function(src = my_test_src()) {
-  if (inherits(src, "src_dbi")) skip("works only locally")
+  if (is_db(src)) skip("works only locally")
 }
 
 skip_if_local_src <- function(src = my_test_src()) {
-  if (inherits(src, "src_local")) skip("works only on a DB")
+  if (!is_db(src)) skip("works only on a DB")
+  skip_if_not_installed("dbplyr")
 }
 
 skip_if_src <- function(name) {
